<?php
/**
 * The template for displaying the header.
 *
 * Displays everything from the doctype declaration down to the navigation.
 *
 * @package Architect
 */

$mts_options = get_option( MTS_THEME_NAME );
?>
<!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?>>
<head itemscope itemtype="http://schema.org/WebSite">
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<!-- Always force latest IE rendering engine (even in intranet) & Chrome Frame -->
	<!--[if IE ]>
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
	<![endif]-->
	<link rel="profile" href="http://gmpg.org/xfn/11" />
	<title><?php wp_title( '|', true, 'right' ); ?></title>
	<?php mts_meta(); ?>
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
	<?php wp_head(); ?>
</head>
<body id ="blog" <?php body_class( 'main' ); ?> itemscope itemtype="http://schema.org/WebPage">       
	<div class="main-container">
		<header class="main-header clearfix" role="banner" itemscope itemtype="http://schema.org/WPHeader" <?php echo ( $mts_options['mts_sticky_header'] == '1' ? 'id="sticky"' : '' ); ?>>
			<div class="container">
				<div id="header">
					<div class="logo-wrap">
						<?php
						if ( ! empty( $mts_options['mts_logo'] ) ) {
							if ( is_front_page() || is_home() || is_404() ) {
								?>
								<h1 id="logo" class="image-logo" itemprop="headline">
									<a href="<?php echo esc_url( home_url() ); ?>"><img src="<?php echo $mts_options['mts_logo']; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>"></a>
								</h1><!-- END #logo -->
								<?php
							} else {
								?>
								<h2 id="logo" class="image-logo" itemprop="headline">
									<a href="<?php echo esc_url( home_url() ); ?>"><img src="<?php echo $mts_options['mts_logo']; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>"></a>
								</h2><!-- END #logo -->
								<?php
							}
						} else {
							if ( is_front_page() || is_home() || is_404() ) {
								?>
								<h1 id="logo" class="text-logo" itemprop="headline">
									<a href="<?php echo esc_url( home_url() ); ?>"><?php bloginfo( 'name' ); ?></a>
								</h1><!-- END #logo -->
								<?php
							} else {
								?>
								<h2 id="logo" class="text-logo" itemprop="headline">
									<a href="<?php echo esc_url( home_url() ); ?>"><?php bloginfo( 'name' ); ?></a>
								</h2><!-- END #logo -->
								<?php
							}
						}
						?>
					</div>
					<?php
					if ( '1' == $mts_options['mts_show_primary_nav'] ) { // phpcs:ignore
						?>
						<div class="primary-navigation" role="navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">
							<nav id="navigation">
								<?php
								if ( '1' == $mts_options['mts_header_search_form'] ) { // phpcs:ignore
									?>
									<div class="header-search">
										<a href="#" class="fa fa-search"></a>
										<form class="search-form" action="<?php echo home_url(); ?>" method="get">
											<input class="hideinput" name="s" id="s" type="search" placeholder="<?php _e('Search...', 'mythemeshop'); ?>" autocomplete="off" />
										</form>
									</div>
									<?php
								}
								?>
								<a href="#" id="pull" class="toggle-mobile-menu"><i class="fa fa-bars"></i></a>
								<?php
								if ( has_nav_menu( 'primary-menu' ) ) {
									$nav_menu_walker = mts_is_wp_mega_menu_active() ? new wpmm_menu_walker : new mts_menu_walker; 
									wp_nav_menu(
										array(
											'theme_location' => 'primary-menu',
											'menu_class'     => 'menu',
											'container'      => '',
											'walker'         => $nav_menu_walker
										)
									);
								} else {
									?>
									<ul class="menu">
										<?php wp_list_pages('title_li='); ?>
									</ul>
									<?php
								}
								?>
							</nav>
						</div>
						<?php
					}
					?>
				</div><!--#header-->
			</div><!--.container-->
		</header>
		<?php
		if ( '1' == $mts_options['mts_sticky_header'] ) { // phpcs:ignore
			?>
			<div id="catcher"></div>
			<?php
		}
		?>
